@@ -94,6 +94,14 @@ class GridShape(BaseShape):
             **kwargs,
         )
         cnv.commit()  # if not, then Page objects e.g. Image not layered
+        # ---- text
+        x = self._u.x + self._o.delta_x
+        y = self._u.y + self._o.delta_y
+        x_d = x + (self.cols * width) / 2.0
+        y_d = y + (self.rows * height) / 2.0
+        self.draw_heading(cnv, ID, x_d, y, **kwargs)
+        self.draw_label(cnv, ID, x_d, y_d, **kwargs)
+        self.draw_title(cnv, ID, x_d, y + (self.rows * height), **kwargs)
 
 
 class DotGridShape(BaseShape):
@@ -133,7 +141,7 @@ class DotGridShape(BaseShape):
         if self.cols == 0:
             self.cols = int((self.page_width) / width) + 1
         # ---- set canvas
-        size = self.dot_point / 2.0  # diameter is 3 points ~ 1mm or 1/32"
+        size = self.dot_width / 2.0  # diameter is 3 points ~ 1mm or 1/32"
         self.fill = self.stroke
         # ---- draw dot grid
         for y_col in range(0, self.rows):
