@@ -246,7 +246,8 @@ BUILT_IN_FONTS = [
     "ZapfDingbats",
 ]
 
-STANDARD_CARD_SIZES = {  # width/height
+STANDARD_CARD_SIZES = {
+    # width/height
     "bridge": {"mm": (57.2, 88.9), "in": (2.25, 3.5), "pt": (162, 252)},
     "business": {"mm": (88.9, 50.8), "in": (3.5, 2), "pt": (252, 144)},
     "mtg": {"mm": (63.5, 88.9), "in": (2.5, 3.5), "pt": (180, 252)},  # poker
@@ -260,6 +261,20 @@ STANDARD_CARD_SIZES = {  # width/height
     "poker": {"mm": (63.5, 88.9), "in": (2.5, 3.5), "pt": (180, 252)},
     "skat": {"mm": (58.9, 90.7), "in": (2.32, 3.58), "pt": (166.96, 257.1)},
     "tarot": {"mm": (69.9, 120.7), "in": (2.75, 4.75), "pt": (198, 342)},
+    # height/width
+    "bridge-l": {"mm": (88.9, 57.2), "in": (3.5, 2.25), "pt": (252, 162)},
+    "business-l": {"mm": (50.8, 88.9), "in": (2, 3.5), "pt": (144, 252)},
+    "mtg-l": {"mm": (88.9, 63.5), "in": (3.5, 2.5), "pt": (252, 180)},  # poker
+    "mini-l": {"mm": (63.5, 44.5), "in": (2.5, 1.75), "pt": (180, 126)},
+    "minieuropean-l": {
+        "mm": (67.0, 44.0),
+        "in": (2.638, 1.732),
+        "pt": (189.921, 124.724),
+    },
+    "miniamerican-l": {"mm": (63.0, 41.0), "in": (2.48, 1.51), "pt": (178.583, 116.22)},
+    "poker-l": {"mm": (88.9, 63.5), "in": (3.5, 2.5), "pt": (252, 180)},
+    "skat-l": {"mm": (90.7, 58.9), "in": (3.58, 2.32), "pt": (257.1, 166.96)},
+    "tarot-l": {"mm": (120.7, 69.9), "in": (4.75, 2.75), "pt": (342, 198)},
 }
 
 PAPER_SIZES = {
